etl\_bq\_tools
==============

|Github License| |Updates| |Python 3| |Code coverage|

etl\_bq\_tools is a Python library that implements bigquery ##
Installation

The code is packaged for PyPI, so that the installation consists in
running:

.. code:: sh

    pip install etl-bq-tools

Usage
-----

wrapper bigquery execution runtime

License
-------

`Apache License
2.0 <https://www.dropbox.com/s/8t6xtgk06o3ij61/LICENSE?dl=0>`__.

New features v1.0
-----------------

BugFix
------

-  choco install visualcpp-build-tools

Reference
---------

-  Jonathan Quiza `github <https://github.com/jonaqp>`__.
-  Jonathan Quiza `RumiMLSpark <http://rumi-ml.herokuapp.com/>`__.
-  Jonathan Quiza `linkedin <https://www.linkedin.com/in/jonaqp/>`__.

.. |Github License| image:: https://img.shields.io/badge/License-Apache%202.0-blue.svg
   :target: https://opensource.org/licenses/Apache-2.0
.. |Updates| image:: https://pyup.io/repos/github/woctezuma/google-colab-transfer/shield.svg
   :target: pyup
.. |Python 3| image:: https://pyup.io/repos/github/woctezuma/google-colab-transfer/python-3-shield.svg
   :target: pyup
.. |Code coverage| image:: https://codecov.io/gh/woctezuma/google-colab-transfer/branch/master/graph/badge.svg
   :target: codecov
